import { useState, useEffect } from 'react';

import { getCategories, addItem } from '../apis/back';

const AddProduct = () => {
  const [categories, setCategories] = useState<any[]>([]);

  const [name, setName] = useState("");
  const [price, setPrice] = useState(0);
  const [priceAdherant, setPriceAdherant] = useState(0);
  const [stock, setStock] = useState(0);
  const [category_id, setCategory] = useState("n/a");

  useEffect(() => {
    getCategories().then((data) => {
      setCategories(data);
    }).catch((_) => {
      setCategories([]);
    });
  }, []);

  function createItem() {
    if (category_id !== "n/a" && name !== "" && price > 0 && priceAdherant > 0 && stock > 0) {
      console.log("Creating item: " + name + " " + price + " " + priceAdherant + " " + stock + " " + category_id);
      addItem(name, price, priceAdherant, stock, category_id).then((data) => {
        //console.log(data);
  
        // Reset form data
        setName("");
        setPrice(0);
        setPriceAdherant(0);
        setStock(0);
        setCategory("n/a");
      }).catch((_) => {
        console.log("Error on creating item");
      });
    } else {
      console.log("Please select a category");
    }
  }

  return (
    <div className="max-w-7xl mx-auto px-4 sm:px-6 md:px-8">
    <div className="pt-8">
      <div className="mb-12">
        <h3 className="text-3xl leading-6 font-medium text-gray-900">Ajouter un produit</h3>
      </div>
      <div className="">
        <div className="mt-5">
          <label htmlFor="name" className="block text-sm font-medium text-gray-700">
            Nom
          </label>
          <div className="mt-1">
            <input
              type="text"
              name="name"
              id="name"
              onChange={(e) => setName(e.target.value)}
              value={name}
              className="shadow-sm focus:ring-indigo-500 focus:border-indigo-500 block w-full sm:text-sm border-gray-300 rounded-md"
            />
          </div>
        </div>

        <div>
          <p className="mt-10 text-xl">Prix</p>
          <div className="flex flex-row w-full mt-3">
            <div className="w-1/2 mr-2">
              <label htmlFor="price" className="block text-sm font-medium text-gray-700">
                Prix (normal)
              </label>
              <div className="mt-1">
                <input
                  type="number"
                  name="price"
                  id="price"
                  onChange={(e) => setPrice(parseFloat(e.target.value))}
                  value={price}
                  min="0.5"
                  placeholder="1.5"
                  step="0.5"
                  className="shadow-sm focus:ring-indigo-500 focus:border-indigo-500 block w-full sm:text-sm border-gray-300 rounded-md"
                />
              </div>
            </div>

            <div className="w-1/2 ml-2">
              <label htmlFor="price-adherant" className="block text-sm font-medium text-gray-700">
                Prix (adhérent)
              </label>
              <div className="mt-1">
                <input
                  type="number"
                  name="price-adherant"
                  id="price-adherant"
                  onChange={(e) => setPriceAdherant(parseFloat(e.target.value))}
                  value={priceAdherant}
                  min="0.5"
                  placeholder="1.5"
                  step="0.5"
                  className="shadow-sm focus:ring-indigo-500 focus:border-indigo-500 block w-full sm:text-sm border-gray-300 rounded-md"
                />
              </div>
            </div>
          </div>
        </div>

        <div>
          <p className="mt-10 text-xl">Catégorie</p>
          <div className="flex flex-row w-full mt-3">
            <div className="w-1/2">
              <div className="mt-1">
                <select
                  id="category"
                  name="category"
                  onChange={(e) => setCategory(e.target.value.toString())}
                  value={category_id}
                  className="shadow-sm focus:ring-indigo-500 focus:border-indigo-500 block w-full sm:text-sm border-gray-300 rounded-md"
                >
                  <option value="0">Choisir une catégorie</option>
                  {categories.map((category) => (
                    <option key={category.id} value={category.id}>
                      {category.name}
                    </option>
                  ))}
                </select>
              </div>
            </div>
          </div>
        </div>

        <div>
          <p className="mt-10 text-xl">Quantité</p>
          <div className="flex flex-row w-full mt-3">
          <div className="w-1/2">
              <div className="mt-1">
                <input
                  type="number"
                  name="quantity"
                  id="quantity"
                  onChange={(e) => setStock(parseInt(e.target.value))}
                  value={stock}
                  min="0"
                  placeholder="1"
                  step="1"
                  className="shadow-sm focus:ring-indigo-500 focus:border-indigo-500 block w-full sm:text-sm border-gray-300 rounded-md"
                />
              </div>
            </div>
          </div>
        </div>

        <button type="button" className="mt-10 w-full sm:w-auto bg-indigo-500 text-white py-2 px-4 rounded-md hover:bg-indigo-600" onClick={() => {createItem()}}>
          Ajouter
        </button>

      </div>
    </div>
    </div>
  )
}

export default AddProduct;